#!/bin/bash
#
# Copyright 2014-2024 by Tom Jampen <tom.jampen@gymkirchenfeld.ch>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.



KINET_DIR="/usr/share/kinet"
EXPECT_SCRIPT="kinet-keyring-save.exp"

KEYRING="/usr/bin/keyring"
SERVICE="KINET"
ACCOUNT="KINET-Account"



# includes
. ${KINET_DIR}/kinet-misc.sh



keyring-ask-for-and-store-kinet-account() {
	if ! $(is-binary-installed "/usr/bin/yad")
	then
		return 1
	fi

	# ask for kinet account
	TITLE="KINET-Benutzerkonto"
	TOKENS=$(yad --form --field="E-Mail-Adresse" --field="Passwort:H" --title="${TITLE}")
	RETVAL=${?}

	# exit if user aborted the login dialog
	if [ ${RETVAL} -ne 0 ]
	then
		return 1
	fi

	USERNAME=$(echo ${TOKENS} | sed -e 's/|.*$//')
	PASSWORD=$(echo ${TOKENS#*|} | sed -e 's/|//')

	keyring-store-kinet-account "${USERNAME}" "${PASSWORD}"
}



keyring-store-kinet-account() {
	# parameters
	local USERNAME="${1}"
	local PASSWORD="${2}"

	# abort if gkeyring is missing
	if ! $(is-binary-installed ${KEYRING})
	then
		return 1
	fi

	# add account to the keyring
	${KINET_DIR}/${EXPECT_SCRIPT} ${SERVICE} ${ACCOUNT} ${USERNAME} ${PASSWORD}

	return ${?}
}



keyring-retrieve-kinet-account() {
	if ! $(is-binary-installed ${KEYRING})
	then
		return 1
	fi

	# retrieve gnome keyring data
	local USER_DATA=$(${KEYRING} get "${SERVICE}" "${ACCOUNT}")
	local REGEXP="^[a-zA-Z0-9._]+@[a-zA-Z0-9._]+[[:space:]].+$"

	# is the user account stored in gnome-keyring
	if [[ ${USER_DATA} =~ ${REGEXP} ]]
	then
		echo ${USER_DATA}
		return 0
	else
		echo "No user data found in gnome keyring."
		return 1
	fi
}



keyring-has-kinet-account() {
	if ! $(is-binary-installed ${KEYRING})
	then
		return 1
	fi

	# retrieve gnome keyring data
	${KEYRING} get "${SERVICE}" "${ACCOUNT}"

	if [ ${?} -eq 0 ]
	then
		return 0
	else
		return 1
	fi
}



keyring-get-username() {
	local USER_DATA="$(keyring-retrieve-kinet-account)"
	local USERNAME="$(echo ${USER_DATA} | awk '{print $1}')"

	if [ -n "${USERNAME}" ]
	then
		echo "${USERNAME}"
		return 0
	else
		echo "Username not found."
		return 1
	fi
}



keyring-get-password() {
	local USER_DATA="$(keyring-retrieve-kinet-account)"
	local PASSWORD="$(echo ${USER_DATA} | awk '{print $2}')"

	if [ -n "${PASSWORD}" ]
	then
		echo "${PASSWORD}"
		return 0
	else
		echo "Password not found."
		return 1
	fi
}



keyring-is-student() {
	local USERNAME="$(keyring-get-username)"
	local REGEXP="^[a-zA-Z0-9._]+@mygymer.ch$"

	# is the user a student (e.g. does the username contain a dot)
	if [[ ${USERNAME} =~ ${REGEXP} ]]
	then
		return 0
	else
		return 1
	fi
}
